[LNT] r345006 - Come up with MIN_PERCENTAGE_CHANGE value.

Martin Liska via llvm-commits llvm-commits at lists.llvm.org
Tue Oct 23 00:08:50 PDT 2018


Author: marxin
Date: Tue Oct 23 00:08:50 2018
New Revision: 345006

URL: http://llvm.org/viewvc/llvm-project?rev=345006&view=rev
Log:
Come up with MIN_PERCENTAGE_CHANGE value.

Differential Revision: https://reviews.llvm.org/D53136

Modified:
    lnt/trunk/lnt/server/db/rules/rule_update_fixed_regressions.py
    lnt/trunk/lnt/server/reporting/analysis.py

Modified: lnt/trunk/lnt/server/db/rules/rule_update_fixed_regressions.py
URL: http://llvm.org/viewvc/llvm-project/lnt/trunk/lnt/server/db/rules/rule_update_fixed_regressions.py?rev=345006&r1=345005&r2=345006&view=diff
==============================================================================
--- lnt/trunk/lnt/server/db/rules/rule_update_fixed_regressions.py (original)
+++ lnt/trunk/lnt/server/db/rules/rule_update_fixed_regressions.py Tue Oct 23 00:08:50 2018
@@ -9,7 +9,7 @@ from lnt.server.db.regression import get
 from lnt.server.db.testsuitedb import TestSuiteDB
 from lnt.testing.util.commands import timed
 from lnt.util import logger
-
+from lnt.server.reporting.analysis import MIN_PERCENTAGE_CHANGE
 
 def _fixed_rind(session, ts, rind):
     """Is this regression indicator fixed?"""
@@ -17,7 +17,7 @@ def _fixed_rind(session, ts, rind):
     if fc is None:
         return False
     current_cr, _, _ = get_cr_for_field_change(session, ts, fc, current=True)
-    if current_cr.pct_delta < 0.01:
+    if current_cr.pct_delta < MIN_PERCENTAGE_CHANGE:
         return True
     else:
         return False

Modified: lnt/trunk/lnt/server/reporting/analysis.py
URL: http://llvm.org/viewvc/llvm-project/lnt/trunk/lnt/server/reporting/analysis.py?rev=345006&r1=345005&r2=345006&view=diff
==============================================================================
--- lnt/trunk/lnt/server/reporting/analysis.py (original)
+++ lnt/trunk/lnt/server/reporting/analysis.py Tue Oct 23 00:08:50 2018
@@ -15,6 +15,8 @@ UNCHANGED_FAIL = 'UNCHANGED_FAIL'
 # The smallest measureable change we can detect in seconds.
 MIN_VALUE_PRECISION = 0.0001
 
+# Minimal percentage difference that is visible in reports
+MIN_PERCENTAGE_CHANGE = .01
 
 def absmin_diff(current, prevs):
     """Min of differences between current sample and all previous samples.
@@ -183,16 +185,16 @@ class ComparisonResult:
         elif self.prev_failed:
             return UNCHANGED_PASS
 
         # Always ignore percentage changes below 1%, for now, we just don't
         # have enough time to investigate that level of stuff.
-        if ignore_small and abs(self.pct_delta) < .01:
+        if ignore_small and abs(self.pct_delta) < MIN_PERCENTAGE_CHANGE:
             return UNCHANGED_PASS
 
         # Always ignore changes with small deltas. There is no mathematical
         # basis for this, it should be obviated by appropriate statistical
         # checks, but practical evidence indicates what we currently have isn't
         # good enough (for reasons I do not yet understand).
-        if ignore_small and abs(self.delta) < .01:
+        if ignore_small and abs(self.delta) < MIN_PERCENTAGE_CHANGE:
             return UNCHANGED_PASS
 
         # Ignore tests whose delta is too small relative to the precision we
@@ -183,16 +185,16 @@ class ComparisonResult:
             return UNCHANGED_PASS
 
-        # Always ignore percentage changes below 1%, for now, we just don't
+        # Always ignore percentage changes below MIN_PERCENTAGE_CHANGE %, for now, we just don't
         # have enough time to investigate that level of stuff.




More information about the llvm-commits mailing list